@@ -10,7 +10,7 @@ use File::Spec ();
 # Globals
 use vars qw{$VERSION @ISA @EXPORT @EXPORT_OK $IMPLEMENTED_BY};
 BEGIN {
-	$VERSION = '0.71_02';
+	$VERSION = '0.71_03';
 
 	# Inherit manually
 	require Exporter;
@@ -25,7 +25,6 @@ BEGIN {
 		my_pictures
 		my_videos
 		my_data
-		my_dot_config
 		users_home
 		users_desktop
 		users_documents
@@ -50,6 +49,7 @@ sub _DRIVER ($$) {
 # Platform detection
 if ( $IMPLEMENTED_BY ) {
 	# Allow for custom HomeDir classes
+	# Leave it as the existing value
 } elsif ( $^O eq 'MSWin32' ) {
 	# All versions of Windows
 	$IMPLEMENTED_BY = 'File::HomeDir::Windows';
@@ -114,11 +114,6 @@ sub my_data {
 		: Carp::croak("The my_data method is not implemented on this platform");
 }
 
-sub my_dot_config {
-	$IMPLEMENTED_BY->can('my_dot_config')
-		? $IMPLEMENTED_BY->my_dot_config
-		: $IMPLEMENTED_BY->my_home;
-}
 
 
 
@@ -457,15 +452,6 @@ C<~/Local Settings/Application Data/.foo>
 Returns the directory path as a string, C<undef> if the current user
 does not have a data directory, or dies on error.
 
-=head2 my_dot_config
-
-The C<my_dot_config> method takes no arguments and returns the directory
-where Unix-style applications should store their internal configuration
-data for the current user. This is the same as C<my_data> on most platforms,
-but whereas C<my_data> is F<~/Library/Application Support> on Mac OS X,
-C<my_dot_config> will instead return the same value as C<my_home>, namely
-F<~/>.
-
 =head2 users_home
 
   $home = File::HomeDir->users_home('foo');
