@@ -5,13 +5,14 @@ package File::HomeDir::Windows;
 
 use 5.005;
 use strict;
-use base 'File::HomeDir::Driver';
-use Carp       ();
+use File::HomeDir::Driver ();
+use Carp ();
 use File::Spec ();
 
-use vars qw{$VERSION};
+use vars qw{$VERSION @ISA};
 BEGIN {
-	$VERSION = '0.71_02';
+	$VERSION = '0.71_03';
+	@ISA     = 'File::HomeDir::Driver';
 }
 
 sub CREATE () { 1 }
